@@ -13,7 +13,7 @@ from typing import Dict, Any, Optional, List
 from collections import OrderedDict
 
 from lambda_deploy.utils.logging import log, debug, section, colorize, success, error, warning
-from lambda_deploy.utils.config_processor import process_configs, OrderedLoader
+from lambda_deploy.utils.config_processor import process_configs, OrderedLoader, get_aws_clients
 
 
 class LambdaDeployer:
@@ -34,10 +34,10 @@ class LambdaDeployer:
         if not self.skip_validation:
             self._validate_aws_credentials()
 
-        # initialize AWS
-        self.ssm = boto3.client('ssm', region_name=self.config.get('region', 'us-east-1'))
-        self.secretsmanager = boto3.client('secretsmanager', region_name=self.config.get('region', 'us-east-1'))
-        self.lambda_client = boto3.client('lambda', region_name=self.config.get('region', 'us-east-1'))
+        # initialize AWS clients
+        self.ssm, self.secretsmanager, self.lambda_client = get_aws_clients(
+            region=self.config.get('region', 'us-east-1')
+        )
 
     def _find_config_file(self, config_dir: str, stage: str) -> str:
         """find config file for stage"""
@@ -88,68 +88,6 @@ class LambdaDeployer:
         """process config templates if present"""
         process_configs(self.config, self.stage, self.config_dir, self.release)
 
-    def _resolve_parameter_store(self, param_path: str) -> str:
-        """get value from Parameter Store"""
-        try:
-            response = self.ssm.get_parameter(Name=param_path, WithDecryption=True)
-            return response['Parameter']['Value']
-        except Exception as e:
-            log(f"Error retrieving parameter {param_path}: {e}")
-            return ""
-
-    def _resolve_secrets_manager(self, secret_id: str) -> str:
-        """get value from SM"""
-        # check for specific key
-        key = None
-        if '::' in secret_id:
-            secret_id, key = secret_id.split('::', 1)
-        try:
-            response = self.secretsmanager.get_secret_value(SecretId=secret_id)
-            secret_string = response['SecretString']
-
-            if key:
-                try:
-                    secret_json = json.loads(secret_string)
-                    if isinstance(secret_json, dict) and key in secret_json:
-                        return str(secret_json[key])
-                    else:
-                        log(f"Warning: Key '{key}' not found in secret JSON or secret is not a JSON object")
-                        return ""
-                except json.JSONDecodeError:
-                    log(f"Warning: Secret is not valid JSON, cannot extract key '{key}'")
-                    return ""
-
-            return secret_string
-        except Exception as e:
-            log(f"Error retrieving secret {secret_id}: {e}")
-            return ""
-
-    def _resolve_env_var(self, var_name: str) -> str:
-        """Get value from environment variables"""
-        return os.environ.get(var_name, "")
-
-    def _resolve_variable(self, value: str) -> str:
-        """resolve variable from various sources"""
-
-        if value.startswith("${env:") and value.endswith("}"):
-            env_var_name = value[6:-1]
-            env_var_value = os.environ.get(env_var_name)
-
-            # Return the original value if the environment variable is not found
-            if env_var_value is None:
-                return value
-
-            return env_var_value
-
-        if value.startswith("arn:aws:ssm:"):
-            return self._resolve_parameter_store(value)
-
-        if value.startswith("arn:aws:secretsmanager:"):
-            return self._resolve_secrets_manager(value)
-
-        # return as is
-        return value
-
     def bootstrap(self) -> None:
         """bootstrap config templates"""
         self._process_config_templates()
@@ -248,10 +186,8 @@ class LambdaDeployer:
             error("function-name not specified in configuration.")
             sys.exit(1)
 
-        full_function_name = f"{self.stage}-{function_name}"
-
         print("\n" + "=" * 80)
-        log(f"Deploying Lambda Function: {colorize(full_function_name, 'BOLD')}", prefix="")
+        log(f"Deploying Lambda Function: {colorize(function_name, 'BOLD')}", prefix="")
         print("=" * 80 + "\n")
 
         # check environment variables file, skip config update if not specified
@@ -281,11 +217,11 @@ class LambdaDeployer:
                 log("Updating Lambda configuration...", color="BLUE")
                 try:
                     self.lambda_client.update_function_configuration(
-                        FunctionName=full_function_name,
+                        FunctionName=function_name,
                         Environment={'Variables': env_vars}
                     )
 
-                    if not self._wait_for_lambda_update(full_function_name):
+                    if not self._wait_for_lambda_update(function_name):
                         error("Failed to update Lambda configuration.")
                         sys.exit(1)
                 except Exception as e:
@@ -330,11 +266,11 @@ class LambdaDeployer:
             log("Updating Lambda function code...", color="BLUE")
             try:
                 self.lambda_client.update_function_code(
-                    FunctionName=full_function_name,
+                    FunctionName=function_name,
                     ZipFile=zip_content
                 )
 
-                if not self._wait_for_lambda_update(full_function_name):
+                if not self._wait_for_lambda_update(function_name):
                     error("Failed to update Lambda code.")
                     sys.exit(1)
             except Exception as e:
@@ -352,11 +288,9 @@ class LambdaDeployer:
             log("Error: function-name not specified in configuration.", color="RED", error=True)
             sys.exit(1)
 
-        full_function_name = f"{self.stage}-{function_name}"
-
         # display header
         print("\n" + "=" * 80)
-        log(f"Lambda Function: {colorize(full_function_name, 'BOLD')}", prefix="")
+        log(f"Lambda Function: {colorize(function_name, 'BOLD')}", prefix="")
         print("=" * 80)
 
         # basic info section
@@ -429,7 +363,7 @@ class LambdaDeployer:
         # get Lambda function info
         try:
             section("Lambda Function Details")
-            response = self.lambda_client.get_function(FunctionName=full_function_name)
+            response = self.lambda_client.get_function(FunctionName=function_name)
             config = response['Configuration']
 
             log(f"Runtime: {colorize(config.get('Runtime', 'Unknown'), 'BRIGHT_GREEN')}")
